#!/bin/sh
#
# Initscript to control the MySQL daemon.
# Ryan W. Maple <ryan@guardiandigital.com>
#
#
# chkconfig: 2345 99 99
# description: Start/stop MySQL
# processname: mysql

# Source function library.
. /etc/init.d/functions

PIDFILE=/var/lib/mysql/mysql.pid
DATADIR=/var/lib/mysql

case "$1" in
  start)
     echo -n "               MySQL DBMS"
     init_term "STARTING"
     /usr/bin/safe_mysqld --user=mysql --pid-file=$PIDFILE \
                          --datadir=$DATADIR >> /dev/null 2>&1 &
     
     ### Print "[ OK ]" or "[ FAILED ]"
     if [ $? -eq 0 ];
     then
       echo_success
     else
       echo_failure
     fi
     
     echo
     touch /var/lock/subsys/mysqld
     ;;
  
  
  stop)
     echo -n "               MySQL DBMS"
     init_term "STOPPING"
     /bin/kill `cat $PIDFILE` > /dev/null 2>&1
     
     ### Print "[ OK ]" or "[ FAILED ]"
     if [ $? -eq 0 ];
     then
       echo_success
     else
       echo_failure
     fi
     
     echo
     rm -f /var/lock/subsys/mysqld
     ;;
  
  
  restart)
     $0 stop
     $0 start
     ;;

  status)
     if [ -f $PIDFILE ];
     then
       echo "MySQL is running with pid `cat $PIDFILE`";
     else
       echo "MySQL is not running."
     fi
     ;;


  *)
     echo "Usage: $0 { start | stop | restart | status}"
     ;;
esac

exit 0

